# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="get_document_statistics_request.py">
#   Copyright (c) 2020 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

class GetDocumentStatisticsRequest(object):
    """
    Request model for get_document_statistics operation.
    Initializes a new instance.
    :param name The document name.
    :param folder Original document folder.
    :param storage Original document storage.
    :param load_encoding Encoding that will be used to load an HTML (or TXT) document if the encoding is not specified in HTML.
    :param password Password for opening an encrypted document.
    :param include_comments Support including/excluding comments from the WordCount. Default value is "false".
    :param include_footnotes Support including/excluding footnotes from the WordCount. Default value is "false".
    :param include_text_in_shapes Support including/excluding shape's text from the WordCount. Default value is "false".
    """

    def __init__(self, name, folder=None, storage=None, load_encoding=None, password=None, include_comments=None, include_footnotes=None, include_text_in_shapes=None):
        self.name = name
        self.folder = folder
        self.storage = storage
        self.load_encoding = load_encoding
        self.password = password
        self.include_comments = include_comments
        self.include_footnotes = include_footnotes
        self.include_text_in_shapes = include_text_in_shapes



# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="delete_table_without_node_path_request.py">
#   Copyright (c) 2020 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------

class DeleteTableWithoutNodePathRequest(object):
    """
    Request model for delete_table_without_node_path operation.
    Initializes a new instance.
    :param name The document name.
    :param index Object index.
    :param folder Original document folder.
    :param storage Original document storage.
    :param load_encoding Encoding that will be used to load an HTML (or TXT) document if the encoding is not specified in HTML.
    :param password Password for opening an encrypted document.
    :param dest_file_name Result path of the document after the operation. If this parameter is omitted then result of the operation will be saved as the source document.
    :param revision_author Initials of the author to use for revisions.If you set this parameter and then make some changes to the document programmatically, save the document and later open the document in MS Word you will see these changes as revisions.
    :param revision_date_time The date and time to use for revisions.
    """

    def __init__(self, name, index, folder=None, storage=None, load_encoding=None, password=None, dest_file_name=None, revision_author=None, revision_date_time=None):
        self.name = name
        self.index = index
        self.folder = folder
        self.storage = storage
        self.load_encoding = load_encoding
        self.password = password
        self.dest_file_name = dest_file_name
        self.revision_author = revision_author
        self.revision_date_time = revision_date_time



from test.Common.test_error_handling import TestErrorHandling
from test.Common.test_font import TestFont
from test.Document.test_document import TestDocument
from test.DocumentActions.test_append_document import TestAppendDocument
from test.DocumentActions.test_classification import TestClassification
from test.DocumentActions.test_compare_document import TestCompareDocument
from test.DocumentActions.test_convert_document import TestConvertDocument
from test.DocumentActions.test_reporting import TestReporting
from test.DocumentActions.test_document_protection import TestDocumentProtection
from test.DocumentActions.test_document_statistics import TestDocumentStatistics
from test.DocumentActions.test_execute_mail_merge import TestExecuteMailMerge
from test.DocumentActions.test_load_web_document import TestLoadWebDocument
from test.DocumentActions.test_mail_merge_fields import TestMailMergeFields
from test.DocumentActions.test_revisions import TestRevisions
from test.DocumentActions.test_split_document import TestSplitDocument
from test.DocumentElements.test_bookmarks import TestBookmarks
from test.DocumentElements.test_comments import TestComments
from test.DocumentElements.test_document_properties import TestDocumentProperties
from test.DocumentElements.test_drawing_objects import TestDrawingObjects
from test.DocumentElements.test_fields import TestFields
from test.DocumentElements.test_footnote import TestFootnote
from test.DocumentElements.test_form_field import TestFormField
from test.DocumentElements.test_header_footer import TestHeaderFooter
from test.DocumentElements.test_hyperlinks import TestHyperlinks
from test.DocumentElements.test_macros import TestMacros
from test.DocumentElements.test_math_objects import TestMathObjects
from test.DocumentElements.test_pages import TestPages
from test.DocumentElements.test_paragraphs import TestParagraphs
from test.DocumentElements.test_runs import TestRuns
from test.DocumentElements.test_sections import TestSections
from test.DocumentElements.test_tables import TestTables
from test.DocumentElements.test_text import TestText
from test.DocumentElements.test_watermarks import TestWatermarks
from test.DocumentElements.test_lists import TestLists
from test.Storage.test_file import TestFile
from test.Storage.test_folder import TestFolder
from test.Range.test_range import TestRange
from test.DocumentElements.test_styles import TestStyles



# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="html_fixed_save_options_data.py">
#   Copyright (c) 2020 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import six


class HtmlFixedSaveOptionsData(object):
    """container class for fixed html save options.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dml3_d_effects_rendering_mode': 'str',
        'dml_effects_rendering_mode': 'str',
        'dml_rendering_mode': 'str',
        'file_name': 'str',
        'save_format': 'str',
        'update_fields': 'bool',
        'update_last_printed_property': 'bool',
        'update_last_saved_time_property': 'bool',
        'update_sdt_content': 'bool',
        'zip_output': 'bool',
        'color_mode': 'str',
        'jpeg_quality': 'int',
        'metafile_rendering_options': 'MetafileRenderingOptionsData',
        'numeral_format': 'str',
        'optimize_output': 'bool',
        'page_count': 'int',
        'page_index': 'int',
        'css_class_names_prefix': 'str',
        'encoding': 'str',
        'export_embedded_css': 'bool',
        'export_embedded_fonts': 'bool',
        'export_embedded_images': 'bool',
        'export_form_fields': 'bool',
        'font_format': 'str',
        'page_horizontal_alignment': 'str',
        'page_margins': 'float',
        'resources_folder': 'str',
        'resources_folder_alias': 'str',
        'save_font_face_css_separately': 'bool',
        'show_page_border': 'bool',
        'use_target_machine_fonts': 'bool'
    }

    attribute_map = {
        'dml3_d_effects_rendering_mode': 'Dml3DEffectsRenderingMode',
        'dml_effects_rendering_mode': 'DmlEffectsRenderingMode',
        'dml_rendering_mode': 'DmlRenderingMode',
        'file_name': 'FileName',
        'save_format': 'SaveFormat',
        'update_fields': 'UpdateFields',
        'update_last_printed_property': 'UpdateLastPrintedProperty',
        'update_last_saved_time_property': 'UpdateLastSavedTimeProperty',
        'update_sdt_content': 'UpdateSdtContent',
        'zip_output': 'ZipOutput',
        'color_mode': 'ColorMode',
        'jpeg_quality': 'JpegQuality',
        'metafile_rendering_options': 'MetafileRenderingOptions',
        'numeral_format': 'NumeralFormat',
        'optimize_output': 'OptimizeOutput',
        'page_count': 'PageCount',
        'page_index': 'PageIndex',
        'css_class_names_prefix': 'CssClassNamesPrefix',
        'encoding': 'Encoding',
        'export_embedded_css': 'ExportEmbeddedCss',
        'export_embedded_fonts': 'ExportEmbeddedFonts',
        'export_embedded_images': 'ExportEmbeddedImages',
        'export_form_fields': 'ExportFormFields',
        'font_format': 'FontFormat',
        'page_horizontal_alignment': 'PageHorizontalAlignment',
        'page_margins': 'PageMargins',
        'resources_folder': 'ResourcesFolder',
        'resources_folder_alias': 'ResourcesFolderAlias',
        'save_font_face_css_separately': 'SaveFontFaceCssSeparately',
        'show_page_border': 'ShowPageBorder',
        'use_target_machine_fonts': 'UseTargetMachineFonts'
    }

    def __init__(self, dml3_d_effects_rendering_mode=None, dml_effects_rendering_mode=None, dml_rendering_mode=None, file_name=None, save_format=None, update_fields=None, update_last_printed_property=None, update_last_saved_time_property=None, update_sdt_content=None, zip_output=None, color_mode=None, jpeg_quality=None, metafile_rendering_options=None, numeral_format=None, optimize_output=None, page_count=None, page_index=None, css_class_names_prefix=None, encoding=None, export_embedded_css=None, export_embedded_fonts=None, export_embedded_images=None, export_form_fields=None, font_format=None, page_horizontal_alignment=None, page_margins=None, resources_folder=None, resources_folder_alias=None, save_font_face_css_separately=None, show_page_border=None, use_target_machine_fonts=None):  # noqa: E501
        """HtmlFixedSaveOptionsData - a model defined in Swagger"""  # noqa: E501

        self._dml3_d_effects_rendering_mode = None
        self._dml_effects_rendering_mode = None
        self._dml_rendering_mode = None
        self._file_name = None
        self._save_format = None
        self._update_fields = None
        self._update_last_printed_property = None
        self._update_last_saved_time_property = None
        self._update_sdt_content = None
        self._zip_output = None
        self._color_mode = None
        self._jpeg_quality = None
        self._metafile_rendering_options = None
        self._numeral_format = None
        self._optimize_output = None
        self._page_count = None
        self._page_index = None
        self._css_class_names_prefix = None
        self._encoding = None
        self._export_embedded_css = None
        self._export_embedded_fonts = None
        self._export_embedded_images = None
        self._export_form_fields = None
        self._font_format = None
        self._page_horizontal_alignment = None
        self._page_margins = None
        self._resources_folder = None
        self._resources_folder_alias = None
        self._save_font_face_css_separately = None
        self._show_page_border = None
        self._use_target_machine_fonts = None
        self.discriminator = None

        if dml3_d_effects_rendering_mode is not None:
            self.dml3_d_effects_rendering_mode = dml3_d_effects_rendering_mode
        if dml_effects_rendering_mode is not None:
            self.dml_effects_rendering_mode = dml_effects_rendering_mode
        if dml_rendering_mode is not None:
            self.dml_rendering_mode = dml_rendering_mode
        if file_name is not None:
            self.file_name = file_name
        if save_format is not None:
            self.save_format = save_format
        if update_fields is not None:
            self.update_fields = update_fields
        if update_last_printed_property is not None:
            self.update_last_printed_property = update_last_printed_property
        if update_last_saved_time_property is not None:
            self.update_last_saved_time_property = update_last_saved_time_property
        if update_sdt_content is not None:
            self.update_sdt_content = update_sdt_content
        if zip_output is not None:
            self.zip_output = zip_output
        if color_mode is not None:
            self.color_mode = color_mode
        if jpeg_quality is not None:
            self.jpeg_quality = jpeg_quality
        if metafile_rendering_options is not None:
            self.metafile_rendering_options = metafile_rendering_options
        if numeral_format is not None:
            self.numeral_format = numeral_format
        if optimize_output is not None:
            self.optimize_output = optimize_output
        if page_count is not None:
            self.page_count = page_count
        if page_index is not None:
            self.page_index = page_index
        if css_class_names_prefix is not None:
            self.css_class_names_prefix = css_class_names_prefix
        if encoding is not None:
            self.encoding = encoding
        if export_embedded_css is not None:
            self.export_embedded_css = export_embedded_css
        if export_embedded_fonts is not None:
            self.export_embedded_fonts = export_embedded_fonts
        if export_embedded_images is not None:
            self.export_embedded_images = export_embedded_images
        if export_form_fields is not None:
            self.export_form_fields = export_form_fields
        if font_format is not None:
            self.font_format = font_format
        if page_horizontal_alignment is not None:
            self.page_horizontal_alignment = page_horizontal_alignment
        if page_margins is not None:
            self.page_margins = page_margins
        if resources_folder is not None:
            self.resources_folder = resources_folder
        if resources_folder_alias is not None:
            self.resources_folder_alias = resources_folder_alias
        if save_font_face_css_separately is not None:
            self.save_font_face_css_separately = save_font_face_css_separately
        if show_page_border is not None:
            self.show_page_border = show_page_border
        if use_target_machine_fonts is not None:
            self.use_target_machine_fonts = use_target_machine_fonts

    @property
    def dml3_d_effects_rendering_mode(self):
        """Gets the dml3_d_effects_rendering_mode of this HtmlFixedSaveOptionsData.  # noqa: E501

        Gets or sets a value determining how 3D effects are rendered.  # noqa: E501

        :return: The dml3_d_effects_rendering_mode of this HtmlFixedSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._dml3_d_effects_rendering_mode

    @dml3_d_effects_rendering_mode.setter
    def dml3_d_effects_rendering_mode(self, dml3_d_effects_rendering_mode):
        """Sets the dml3_d_effects_rendering_mode of this HtmlFixedSaveOptionsData.

        Gets or sets a value determining how 3D effects are rendered.  # noqa: E501

        :param dml3_d_effects_rendering_mode: The dml3_d_effects_rendering_mode of this HtmlFixedSaveOptionsData.  # noqa: E501
        :type: str
        """
        allowed_values = ["Basic", "Advanced"]  # noqa: E501
        if not dml3_d_effects_rendering_mode.isdigit():
            if dml3_d_effects_rendering_mode not in allowed_values:
                raise ValueError(
                    "Invalid value for `dml3_d_effects_rendering_mode` ({0}), must be one of {1}"  # noqa: E501
                    .format(dml3_d_effects_rendering_mode, allowed_values))
            self._dml3_d_effects_rendering_mode = dml3_d_effects_rendering_mode
        else:
            self._dml3_d_effects_rendering_mode = allowed_values[int(dml3_d_effects_rendering_mode) if six.PY3 else long(dml3_d_effects_rendering_mode)]

    @property
    def dml_effects_rendering_mode(self):
        """Gets the dml_effects_rendering_mode of this HtmlFixedSaveOptionsData.  # noqa: E501

        Gets or sets a value determining how DrawingML effects are rendered. { Simplified | None | Fine }.  # noqa: E501

        :return: The dml_effects_rendering_mode of this HtmlFixedSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._dml_effects_rendering_mode

    @dml_effects_rendering_mode.setter
    def dml_effects_rendering_mode(self, dml_effects_rendering_mode):
        """Sets the dml_effects_rendering_mode of this HtmlFixedSaveOptionsData.

        Gets or sets a value determining how DrawingML effects are rendered. { Simplified | None | Fine }.  # noqa: E501

        :param dml_effects_rendering_mode: The dml_effects_rendering_mode of this HtmlFixedSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._dml_effects_rendering_mode = dml_effects_rendering_mode

    @property
    def dml_rendering_mode(self):
        """Gets the dml_rendering_mode of this HtmlFixedSaveOptionsData.  # noqa: E501

        Gets or sets a value determining how DrawingML shapes are rendered. { Fallback | DrawingML }.  # noqa: E501

        :return: The dml_rendering_mode of this HtmlFixedSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._dml_rendering_mode

    @dml_rendering_mode.setter
    def dml_rendering_mode(self, dml_rendering_mode):
        """Sets the dml_rendering_mode of this HtmlFixedSaveOptionsData.

        Gets or sets a value determining how DrawingML shapes are rendered. { Fallback | DrawingML }.  # noqa: E501

        :param dml_rendering_mode: The dml_rendering_mode of this HtmlFixedSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._dml_rendering_mode = dml_rendering_mode

    @property
    def file_name(self):
        """Gets the file_name of this HtmlFixedSaveOptionsData.  # noqa: E501

        Gets or sets name of destination file.  # noqa: E501

        :return: The file_name of this HtmlFixedSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this HtmlFixedSaveOptionsData.

        Gets or sets name of destination file.  # noqa: E501

        :param file_name: The file_name of this HtmlFixedSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._file_name = file_name

    @property
    def save_format(self):
        """Gets the save_format of this HtmlFixedSaveOptionsData.  # noqa: E501

        Gets or sets format of save.  # noqa: E501

        :return: The save_format of this HtmlFixedSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._save_format

    @save_format.setter
    def save_format(self, save_format):
        """Sets the save_format of this HtmlFixedSaveOptionsData.

        Gets or sets format of save.  # noqa: E501

        :param save_format: The save_format of this HtmlFixedSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._save_format = save_format

    @property
    def update_fields(self):
        """Gets the update_fields of this HtmlFixedSaveOptionsData.  # noqa: E501

        Gets or sets a value determining if fields should be updated before saving the document to a fixed page format. Default value for this property is. true.  # noqa: E501

        :return: The update_fields of this HtmlFixedSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._update_fields

    @update_fields.setter
    def update_fields(self, update_fields):
        """Sets the update_fields of this HtmlFixedSaveOptionsData.

        Gets or sets a value determining if fields should be updated before saving the document to a fixed page format. Default value for this property is. true.  # noqa: E501

        :param update_fields: The update_fields of this HtmlFixedSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._update_fields = update_fields

    @property
    def update_last_printed_property(self):
        """Gets the update_last_printed_property of this HtmlFixedSaveOptionsData.  # noqa: E501

        Gets or sets a value determining whether the Aspose.Words.Properties.BuiltInDocumentProperties.LastPrinted property is updated before saving.  # noqa: E501

        :return: The update_last_printed_property of this HtmlFixedSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._update_last_printed_property

    @update_last_printed_property.setter
    def update_last_printed_property(self, update_last_printed_property):
        """Sets the update_last_printed_property of this HtmlFixedSaveOptionsData.

        Gets or sets a value determining whether the Aspose.Words.Properties.BuiltInDocumentProperties.LastPrinted property is updated before saving.  # noqa: E501

        :param update_last_printed_property: The update_last_printed_property of this HtmlFixedSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._update_last_printed_property = update_last_printed_property

    @property
    def update_last_saved_time_property(self):
        """Gets the update_last_saved_time_property of this HtmlFixedSaveOptionsData.  # noqa: E501

        Gets or sets a value determining whether the Aspose.Words.Properties.BuiltInDocumentProperties.LastSavedTime property is updated before saving.  # noqa: E501

        :return: The update_last_saved_time_property of this HtmlFixedSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._update_last_saved_time_property

    @update_last_saved_time_property.setter
    def update_last_saved_time_property(self, update_last_saved_time_property):
        """Sets the update_last_saved_time_property of this HtmlFixedSaveOptionsData.

        Gets or sets a value determining whether the Aspose.Words.Properties.BuiltInDocumentProperties.LastSavedTime property is updated before saving.  # noqa: E501

        :param update_last_saved_time_property: The update_last_saved_time_property of this HtmlFixedSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._update_last_saved_time_property = update_last_saved_time_property

    @property
    def update_sdt_content(self):
        """Gets the update_sdt_content of this HtmlFixedSaveOptionsData.  # noqa: E501

        Gets or sets value determining whether content of StructuredDocumentTag is updated before saving.  # noqa: E501

        :return: The update_sdt_content of this HtmlFixedSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._update_sdt_content

    @update_sdt_content.setter
    def update_sdt_content(self, update_sdt_content):
        """Sets the update_sdt_content of this HtmlFixedSaveOptionsData.

        Gets or sets value determining whether content of StructuredDocumentTag is updated before saving.  # noqa: E501

        :param update_sdt_content: The update_sdt_content of this HtmlFixedSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._update_sdt_content = update_sdt_content

    @property
    def zip_output(self):
        """Gets the zip_output of this HtmlFixedSaveOptionsData.  # noqa: E501

        Gets or sets controls zip output or not. Default value is false.  # noqa: E501

        :return: The zip_output of this HtmlFixedSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._zip_output

    @zip_output.setter
    def zip_output(self, zip_output):
        """Sets the zip_output of this HtmlFixedSaveOptionsData.

        Gets or sets controls zip output or not. Default value is false.  # noqa: E501

        :param zip_output: The zip_output of this HtmlFixedSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._zip_output = zip_output

    @property
    def color_mode(self):
        """Gets the color_mode of this HtmlFixedSaveOptionsData.  # noqa: E501

        Gets or sets a value determining how colors are rendered. { Normal | Grayscale}.  # noqa: E501

        :return: The color_mode of this HtmlFixedSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._color_mode

    @color_mode.setter
    def color_mode(self, color_mode):
        """Sets the color_mode of this HtmlFixedSaveOptionsData.

        Gets or sets a value determining how colors are rendered. { Normal | Grayscale}.  # noqa: E501

        :param color_mode: The color_mode of this HtmlFixedSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._color_mode = color_mode

    @property
    def jpeg_quality(self):
        """Gets the jpeg_quality of this HtmlFixedSaveOptionsData.  # noqa: E501

        Gets or sets determines the quality of the JPEG images inside PDF document.  # noqa: E501

        :return: The jpeg_quality of this HtmlFixedSaveOptionsData.  # noqa: E501
        :rtype: int
        """
        return self._jpeg_quality

    @jpeg_quality.setter
    def jpeg_quality(self, jpeg_quality):
        """Sets the jpeg_quality of this HtmlFixedSaveOptionsData.

        Gets or sets determines the quality of the JPEG images inside PDF document.  # noqa: E501

        :param jpeg_quality: The jpeg_quality of this HtmlFixedSaveOptionsData.  # noqa: E501
        :type: int
        """
        self._jpeg_quality = jpeg_quality

    @property
    def metafile_rendering_options(self):
        """Gets the metafile_rendering_options of this HtmlFixedSaveOptionsData.  # noqa: E501

        Gets or sets allows to specify metafile rendering options.  # noqa: E501

        :return: The metafile_rendering_options of this HtmlFixedSaveOptionsData.  # noqa: E501
        :rtype: MetafileRenderingOptionsData
        """
        return self._metafile_rendering_options

    @metafile_rendering_options.setter
    def metafile_rendering_options(self, metafile_rendering_options):
        """Sets the metafile_rendering_options of this HtmlFixedSaveOptionsData.

        Gets or sets allows to specify metafile rendering options.  # noqa: E501

        :param metafile_rendering_options: The metafile_rendering_options of this HtmlFixedSaveOptionsData.  # noqa: E501
        :type: MetafileRenderingOptionsData
        """
        self._metafile_rendering_options = metafile_rendering_options

    @property
    def numeral_format(self):
        """Gets the numeral_format of this HtmlFixedSaveOptionsData.  # noqa: E501

        Gets or sets indicates the symbol set that is used to represent numbers while rendering to fixed page formats.  # noqa: E501

        :return: The numeral_format of this HtmlFixedSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._numeral_format

    @numeral_format.setter
    def numeral_format(self, numeral_format):
        """Sets the numeral_format of this HtmlFixedSaveOptionsData.

        Gets or sets indicates the symbol set that is used to represent numbers while rendering to fixed page formats.  # noqa: E501

        :param numeral_format: The numeral_format of this HtmlFixedSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._numeral_format = numeral_format

    @property
    def optimize_output(self):
        """Gets the optimize_output of this HtmlFixedSaveOptionsData.  # noqa: E501

        Gets or sets flag indicates whether it is required to optimize output of XPS. If this flag is set redundant nested canvases and empty canvases are removed, also neighbor glyphs with the same formatting are concatenated. Note: The accuracy of the content display may be affected if this property is set to true.  Default is false.  # noqa: E501

        :return: The optimize_output of this HtmlFixedSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._optimize_output

    @optimize_output.setter
    def optimize_output(self, optimize_output):
        """Sets the optimize_output of this HtmlFixedSaveOptionsData.

        Gets or sets flag indicates whether it is required to optimize output of XPS. If this flag is set redundant nested canvases and empty canvases are removed, also neighbor glyphs with the same formatting are concatenated. Note: The accuracy of the content display may be affected if this property is set to true.  Default is false.  # noqa: E501

        :param optimize_output: The optimize_output of this HtmlFixedSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._optimize_output = optimize_output

    @property
    def page_count(self):
        """Gets the page_count of this HtmlFixedSaveOptionsData.  # noqa: E501

        Gets or sets determines number of pages to render.  # noqa: E501

        :return: The page_count of this HtmlFixedSaveOptionsData.  # noqa: E501
        :rtype: int
        """
        return self._page_count

    @page_count.setter
    def page_count(self, page_count):
        """Sets the page_count of this HtmlFixedSaveOptionsData.

        Gets or sets determines number of pages to render.  # noqa: E501

        :param page_count: The page_count of this HtmlFixedSaveOptionsData.  # noqa: E501
        :type: int
        """
        self._page_count = page_count

    @property
    def page_index(self):
        """Gets the page_index of this HtmlFixedSaveOptionsData.  # noqa: E501

        Gets or sets determines 0-based index of the first page to render.  # noqa: E501

        :return: The page_index of this HtmlFixedSaveOptionsData.  # noqa: E501
        :rtype: int
        """
        return self._page_index

    @page_index.setter
    def page_index(self, page_index):
        """Sets the page_index of this HtmlFixedSaveOptionsData.

        Gets or sets determines 0-based index of the first page to render.  # noqa: E501

        :param page_index: The page_index of this HtmlFixedSaveOptionsData.  # noqa: E501
        :type: int
        """
        self._page_index = page_index

    @property
    def css_class_names_prefix(self):
        """Gets the css_class_names_prefix of this HtmlFixedSaveOptionsData.  # noqa: E501

        Gets or sets specifies prefix which is added to all class names in style.css file. Default value is "aw".  # noqa: E501

        :return: The css_class_names_prefix of this HtmlFixedSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._css_class_names_prefix

    @css_class_names_prefix.setter
    def css_class_names_prefix(self, css_class_names_prefix):
        """Sets the css_class_names_prefix of this HtmlFixedSaveOptionsData.

        Gets or sets specifies prefix which is added to all class names in style.css file. Default value is "aw".  # noqa: E501

        :param css_class_names_prefix: The css_class_names_prefix of this HtmlFixedSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._css_class_names_prefix = css_class_names_prefix

    @property
    def encoding(self):
        """Gets the encoding of this HtmlFixedSaveOptionsData.  # noqa: E501

        Gets or sets encoding.  # noqa: E501

        :return: The encoding of this HtmlFixedSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._encoding

    @encoding.setter
    def encoding(self, encoding):
        """Sets the encoding of this HtmlFixedSaveOptionsData.

        Gets or sets encoding.  # noqa: E501

        :param encoding: The encoding of this HtmlFixedSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._encoding = encoding

    @property
    def export_embedded_css(self):
        """Gets the export_embedded_css of this HtmlFixedSaveOptionsData.  # noqa: E501

        Gets or sets specifies whether the CSS (Cascading Style Sheet) should be embedded into Html document.  # noqa: E501

        :return: The export_embedded_css of this HtmlFixedSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._export_embedded_css

    @export_embedded_css.setter
    def export_embedded_css(self, export_embedded_css):
        """Sets the export_embedded_css of this HtmlFixedSaveOptionsData.

        Gets or sets specifies whether the CSS (Cascading Style Sheet) should be embedded into Html document.  # noqa: E501

        :param export_embedded_css: The export_embedded_css of this HtmlFixedSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._export_embedded_css = export_embedded_css

    @property
    def export_embedded_fonts(self):
        """Gets the export_embedded_fonts of this HtmlFixedSaveOptionsData.  # noqa: E501

        Gets or sets specifies whether fonts should be embedded into Html document in Base64 format.  # noqa: E501

        :return: The export_embedded_fonts of this HtmlFixedSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._export_embedded_fonts

    @export_embedded_fonts.setter
    def export_embedded_fonts(self, export_embedded_fonts):
        """Sets the export_embedded_fonts of this HtmlFixedSaveOptionsData.

        Gets or sets specifies whether fonts should be embedded into Html document in Base64 format.  # noqa: E501

        :param export_embedded_fonts: The export_embedded_fonts of this HtmlFixedSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._export_embedded_fonts = export_embedded_fonts

    @property
    def export_embedded_images(self):
        """Gets the export_embedded_images of this HtmlFixedSaveOptionsData.  # noqa: E501

        Gets or sets specifies whether images should be embedded into Html document in Base64 format.  # noqa: E501

        :return: The export_embedded_images of this HtmlFixedSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._export_embedded_images

    @export_embedded_images.setter
    def export_embedded_images(self, export_embedded_images):
        """Sets the export_embedded_images of this HtmlFixedSaveOptionsData.

        Gets or sets specifies whether images should be embedded into Html document in Base64 format.  # noqa: E501

        :param export_embedded_images: The export_embedded_images of this HtmlFixedSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._export_embedded_images = export_embedded_images

    @property
    def export_form_fields(self):
        """Gets the export_form_fields of this HtmlFixedSaveOptionsData.  # noqa: E501

        Gets or sets indication of whether form fields are exported as interactive items (as 'input' tag) rather than converted to text or graphics.  # noqa: E501

        :return: The export_form_fields of this HtmlFixedSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._export_form_fields

    @export_form_fields.setter
    def export_form_fields(self, export_form_fields):
        """Sets the export_form_fields of this HtmlFixedSaveOptionsData.

        Gets or sets indication of whether form fields are exported as interactive items (as 'input' tag) rather than converted to text or graphics.  # noqa: E501

        :param export_form_fields: The export_form_fields of this HtmlFixedSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._export_form_fields = export_form_fields

    @property
    def font_format(self):
        """Gets the font_format of this HtmlFixedSaveOptionsData.  # noqa: E501

        Gets or sets specifies export format of fonts.  # noqa: E501

        :return: The font_format of this HtmlFixedSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._font_format

    @font_format.setter
    def font_format(self, font_format):
        """Sets the font_format of this HtmlFixedSaveOptionsData.

        Gets or sets specifies export format of fonts.  # noqa: E501

        :param font_format: The font_format of this HtmlFixedSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._font_format = font_format

    @property
    def page_horizontal_alignment(self):
        """Gets the page_horizontal_alignment of this HtmlFixedSaveOptionsData.  # noqa: E501

        Gets or sets specifies the horizontal alignment of pages in an HTML document. Default value is HtmlFixedHorizontalPageAlignment.Center.  # noqa: E501

        :return: The page_horizontal_alignment of this HtmlFixedSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._page_horizontal_alignment

    @page_horizontal_alignment.setter
    def page_horizontal_alignment(self, page_horizontal_alignment):
        """Sets the page_horizontal_alignment of this HtmlFixedSaveOptionsData.

        Gets or sets specifies the horizontal alignment of pages in an HTML document. Default value is HtmlFixedHorizontalPageAlignment.Center.  # noqa: E501

        :param page_horizontal_alignment: The page_horizontal_alignment of this HtmlFixedSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._page_horizontal_alignment = page_horizontal_alignment

    @property
    def page_margins(self):
        """Gets the page_margins of this HtmlFixedSaveOptionsData.  # noqa: E501

        Gets or sets specifies the margins around pages in an HTML document. The margins value is measured in points and should be equal to or greater than 0. Default value is 10 points.  # noqa: E501

        :return: The page_margins of this HtmlFixedSaveOptionsData.  # noqa: E501
        :rtype: float
        """
        return self._page_margins

    @page_margins.setter
    def page_margins(self, page_margins):
        """Sets the page_margins of this HtmlFixedSaveOptionsData.

        Gets or sets specifies the margins around pages in an HTML document. The margins value is measured in points and should be equal to or greater than 0. Default value is 10 points.  # noqa: E501

        :param page_margins: The page_margins of this HtmlFixedSaveOptionsData.  # noqa: E501
        :type: float
        """
        self._page_margins = page_margins

    @property
    def resources_folder(self):
        """Gets the resources_folder of this HtmlFixedSaveOptionsData.  # noqa: E501

        Gets or sets specifies the physical folder where resources are saved when exporting a document.  # noqa: E501

        :return: The resources_folder of this HtmlFixedSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._resources_folder

    @resources_folder.setter
    def resources_folder(self, resources_folder):
        """Sets the resources_folder of this HtmlFixedSaveOptionsData.

        Gets or sets specifies the physical folder where resources are saved when exporting a document.  # noqa: E501

        :param resources_folder: The resources_folder of this HtmlFixedSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._resources_folder = resources_folder

    @property
    def resources_folder_alias(self):
        """Gets the resources_folder_alias of this HtmlFixedSaveOptionsData.  # noqa: E501

        Gets or sets specifies the name of the folder used to construct resource URIs.  # noqa: E501

        :return: The resources_folder_alias of this HtmlFixedSaveOptionsData.  # noqa: E501
        :rtype: str
        """
        return self._resources_folder_alias

    @resources_folder_alias.setter
    def resources_folder_alias(self, resources_folder_alias):
        """Sets the resources_folder_alias of this HtmlFixedSaveOptionsData.

        Gets or sets specifies the name of the folder used to construct resource URIs.  # noqa: E501

        :param resources_folder_alias: The resources_folder_alias of this HtmlFixedSaveOptionsData.  # noqa: E501
        :type: str
        """
        self._resources_folder_alias = resources_folder_alias

    @property
    def save_font_face_css_separately(self):
        """Gets the save_font_face_css_separately of this HtmlFixedSaveOptionsData.  # noqa: E501

        Gets or sets flag indicates whether "@font-face" CSS rules should be placed into a separate file "fontFaces.css" when a document is being saved with external stylesheet (that is, when Aspose.Words.Saving.HtmlFixedSaveOptions.ExportEmbeddedCss is false). Default value is false, all CSS rules are written into single file "styles.css".  # noqa: E501

        :return: The save_font_face_css_separately of this HtmlFixedSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._save_font_face_css_separately

    @save_font_face_css_separately.setter
    def save_font_face_css_separately(self, save_font_face_css_separately):
        """Sets the save_font_face_css_separately of this HtmlFixedSaveOptionsData.

        Gets or sets flag indicates whether "@font-face" CSS rules should be placed into a separate file "fontFaces.css" when a document is being saved with external stylesheet (that is, when Aspose.Words.Saving.HtmlFixedSaveOptions.ExportEmbeddedCss is false). Default value is false, all CSS rules are written into single file "styles.css".  # noqa: E501

        :param save_font_face_css_separately: The save_font_face_css_separately of this HtmlFixedSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._save_font_face_css_separately = save_font_face_css_separately

    @property
    def show_page_border(self):
        """Gets the show_page_border of this HtmlFixedSaveOptionsData.  # noqa: E501

        Gets or sets specifies whether border around pages should be shown.  # noqa: E501

        :return: The show_page_border of this HtmlFixedSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._show_page_border

    @show_page_border.setter
    def show_page_border(self, show_page_border):
        """Sets the show_page_border of this HtmlFixedSaveOptionsData.

        Gets or sets specifies whether border around pages should be shown.  # noqa: E501

        :param show_page_border: The show_page_border of this HtmlFixedSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._show_page_border = show_page_border

    @property
    def use_target_machine_fonts(self):
        """Gets the use_target_machine_fonts of this HtmlFixedSaveOptionsData.  # noqa: E501

        Gets or sets flag indicates whether fonts from target machine must be used to display the document. If this flag is set to true, Aspose.Words.Saving.HtmlFixedSaveOptions.FontFormat and Aspose.Words.Saving.HtmlFixedSaveOptions.ExportEmbeddedFonts properties do not have effect, also Aspose.Words.Saving.HtmlFixedSaveOptions.ResourceSavingCallback is not fired for fonts. Default is false.  # noqa: E501

        :return: The use_target_machine_fonts of this HtmlFixedSaveOptionsData.  # noqa: E501
        :rtype: bool
        """
        return self._use_target_machine_fonts

    @use_target_machine_fonts.setter
    def use_target_machine_fonts(self, use_target_machine_fonts):
        """Sets the use_target_machine_fonts of this HtmlFixedSaveOptionsData.

        Gets or sets flag indicates whether fonts from target machine must be used to display the document. If this flag is set to true, Aspose.Words.Saving.HtmlFixedSaveOptions.FontFormat and Aspose.Words.Saving.HtmlFixedSaveOptions.ExportEmbeddedFonts properties do not have effect, also Aspose.Words.Saving.HtmlFixedSaveOptions.ResourceSavingCallback is not fired for fonts. Default is false.  # noqa: E501

        :param use_target_machine_fonts: The use_target_machine_fonts of this HtmlFixedSaveOptionsData.  # noqa: E501
        :type: bool
        """
        self._use_target_machine_fonts = use_target_machine_fonts


    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HtmlFixedSaveOptionsData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


# coding: utf-8
# -----------------------------------------------------------------------------------
# <copyright company="Aspose" file="table_insert.py">
#   Copyright (c) 2020 Aspose.Words for Cloud
# </copyright>
# <summary>
#   Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#  SOFTWARE.
# </summary>
# -----------------------------------------------------------------------------------
import pprint
import re  # noqa: F401

import six


class TableInsert(object):
    """Table element.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'columns_count': 'int',
        'position': 'DocumentPosition',
        'rows_count': 'int'
    }

    attribute_map = {
        'columns_count': 'ColumnsCount',
        'position': 'Position',
        'rows_count': 'RowsCount'
    }

    def __init__(self, columns_count=None, position=None, rows_count=None):  # noqa: E501
        """TableInsert - a model defined in Swagger"""  # noqa: E501

        self._columns_count = None
        self._position = None
        self._rows_count = None
        self.discriminator = None

        if columns_count is not None:
            self.columns_count = columns_count
        if position is not None:
            self.position = position
        if rows_count is not None:
            self.rows_count = rows_count

    @property
    def columns_count(self):
        """Gets the columns_count of this TableInsert.  # noqa: E501

        Gets or sets count of columns. Default is 2.  # noqa: E501

        :return: The columns_count of this TableInsert.  # noqa: E501
        :rtype: int
        """
        return self._columns_count

    @columns_count.setter
    def columns_count(self, columns_count):
        """Sets the columns_count of this TableInsert.

        Gets or sets count of columns. Default is 2.  # noqa: E501

        :param columns_count: The columns_count of this TableInsert.  # noqa: E501
        :type: int
        """
        self._columns_count = columns_count

    @property
    def position(self):
        """Gets the position of this TableInsert.  # noqa: E501

        Gets or sets table will be inserted before specified position.  # noqa: E501

        :return: The position of this TableInsert.  # noqa: E501
        :rtype: DocumentPosition
        """
        return self._position

    @position.setter
    def position(self, position):
        """Sets the position of this TableInsert.

        Gets or sets table will be inserted before specified position.  # noqa: E501

        :param position: The position of this TableInsert.  # noqa: E501
        :type: DocumentPosition
        """
        self._position = position

    @property
    def rows_count(self):
        """Gets the rows_count of this TableInsert.  # noqa: E501

        Gets or sets count of rows. Default is 2.  # noqa: E501

        :return: The rows_count of this TableInsert.  # noqa: E501
        :rtype: int
        """
        return self._rows_count

    @rows_count.setter
    def rows_count(self, rows_count):
        """Sets the rows_count of this TableInsert.

        Gets or sets count of rows. Default is 2.  # noqa: E501

        :param rows_count: The rows_count of this TableInsert.  # noqa: E501
        :type: int
        """
        self._rows_count = rows_count


    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TableInsert):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


from asposewordscloud.models.requests.accept_all_revisions_request import AcceptAllRevisionsRequest
from asposewordscloud.models.requests.append_document_request import AppendDocumentRequest
from asposewordscloud.models.requests.apply_style_to_document_element_request import ApplyStyleToDocumentElementRequest
from asposewordscloud.models.requests.build_report_request import BuildReportRequest
from asposewordscloud.models.requests.build_report_online_request import BuildReportOnlineRequest
from asposewordscloud.models.requests.classify_request import ClassifyRequest
from asposewordscloud.models.requests.classify_document_request import ClassifyDocumentRequest
from asposewordscloud.models.requests.compare_document_request import CompareDocumentRequest
from asposewordscloud.models.requests.convert_document_request import ConvertDocumentRequest
from asposewordscloud.models.requests.copy_file_request import CopyFileRequest
from asposewordscloud.models.requests.copy_folder_request import CopyFolderRequest
from asposewordscloud.models.requests.copy_style_request import CopyStyleRequest
from asposewordscloud.models.requests.create_document_request import CreateDocumentRequest
from asposewordscloud.models.requests.create_folder_request import CreateFolderRequest
from asposewordscloud.models.requests.create_or_update_document_property_request import CreateOrUpdateDocumentPropertyRequest
from asposewordscloud.models.requests.delete_all_paragraph_tab_stops_request import DeleteAllParagraphTabStopsRequest
from asposewordscloud.models.requests.delete_all_paragraph_tab_stops_without_node_path_request import DeleteAllParagraphTabStopsWithoutNodePathRequest
from asposewordscloud.models.requests.delete_border_request import DeleteBorderRequest
from asposewordscloud.models.requests.delete_borders_request import DeleteBordersRequest
from asposewordscloud.models.requests.delete_comment_request import DeleteCommentRequest
from asposewordscloud.models.requests.delete_document_property_request import DeleteDocumentPropertyRequest
from asposewordscloud.models.requests.delete_drawing_object_request import DeleteDrawingObjectRequest
from asposewordscloud.models.requests.delete_drawing_object_without_node_path_request import DeleteDrawingObjectWithoutNodePathRequest
from asposewordscloud.models.requests.delete_field_request import DeleteFieldRequest
from asposewordscloud.models.requests.delete_fields_request import DeleteFieldsRequest
from asposewordscloud.models.requests.delete_fields_without_node_path_request import DeleteFieldsWithoutNodePathRequest
from asposewordscloud.models.requests.delete_field_without_node_path_request import DeleteFieldWithoutNodePathRequest
from asposewordscloud.models.requests.delete_file_request import DeleteFileRequest
from asposewordscloud.models.requests.delete_folder_request import DeleteFolderRequest
from asposewordscloud.models.requests.delete_footnote_request import DeleteFootnoteRequest
from asposewordscloud.models.requests.delete_footnote_without_node_path_request import DeleteFootnoteWithoutNodePathRequest
from asposewordscloud.models.requests.delete_form_field_request import DeleteFormFieldRequest
from asposewordscloud.models.requests.delete_form_field_without_node_path_request import DeleteFormFieldWithoutNodePathRequest
from asposewordscloud.models.requests.delete_header_footer_request import DeleteHeaderFooterRequest
from asposewordscloud.models.requests.delete_headers_footers_request import DeleteHeadersFootersRequest
from asposewordscloud.models.requests.delete_macros_request import DeleteMacrosRequest
from asposewordscloud.models.requests.delete_office_math_object_request import DeleteOfficeMathObjectRequest
from asposewordscloud.models.requests.delete_office_math_object_without_node_path_request import DeleteOfficeMathObjectWithoutNodePathRequest
from asposewordscloud.models.requests.delete_paragraph_request import DeleteParagraphRequest
from asposewordscloud.models.requests.delete_paragraph_list_format_request import DeleteParagraphListFormatRequest
from asposewordscloud.models.requests.delete_paragraph_list_format_without_node_path_request import DeleteParagraphListFormatWithoutNodePathRequest
from asposewordscloud.models.requests.delete_paragraph_tab_stop_request import DeleteParagraphTabStopRequest
from asposewordscloud.models.requests.delete_paragraph_tab_stop_without_node_path_request import DeleteParagraphTabStopWithoutNodePathRequest
from asposewordscloud.models.requests.delete_paragraph_without_node_path_request import DeleteParagraphWithoutNodePathRequest
from asposewordscloud.models.requests.delete_run_request import DeleteRunRequest
from asposewordscloud.models.requests.delete_section_request import DeleteSectionRequest
from asposewordscloud.models.requests.delete_table_request import DeleteTableRequest
from asposewordscloud.models.requests.delete_table_cell_request import DeleteTableCellRequest
from asposewordscloud.models.requests.delete_table_row_request import DeleteTableRowRequest
from asposewordscloud.models.requests.delete_table_without_node_path_request import DeleteTableWithoutNodePathRequest
from asposewordscloud.models.requests.delete_watermark_request import DeleteWatermarkRequest
from asposewordscloud.models.requests.download_file_request import DownloadFileRequest
from asposewordscloud.models.requests.execute_mail_merge_request import ExecuteMailMergeRequest
from asposewordscloud.models.requests.execute_mail_merge_online_request import ExecuteMailMergeOnlineRequest
from asposewordscloud.models.requests.get_available_fonts_request import GetAvailableFontsRequest
from asposewordscloud.models.requests.get_bookmark_by_name_request import GetBookmarkByNameRequest
from asposewordscloud.models.requests.get_bookmarks_request import GetBookmarksRequest
from asposewordscloud.models.requests.get_border_request import GetBorderRequest
from asposewordscloud.models.requests.get_borders_request import GetBordersRequest
from asposewordscloud.models.requests.get_comment_request import GetCommentRequest
from asposewordscloud.models.requests.get_comments_request import GetCommentsRequest
from asposewordscloud.models.requests.get_document_request import GetDocumentRequest
from asposewordscloud.models.requests.get_document_drawing_object_by_index_request import GetDocumentDrawingObjectByIndexRequest
from asposewordscloud.models.requests.get_document_drawing_object_by_index_without_node_path_request import GetDocumentDrawingObjectByIndexWithoutNodePathRequest
from asposewordscloud.models.requests.get_document_drawing_object_image_data_request import GetDocumentDrawingObjectImageDataRequest
from asposewordscloud.models.requests.get_document_drawing_object_image_data_without_node_path_request import GetDocumentDrawingObjectImageDataWithoutNodePathRequest
from asposewordscloud.models.requests.get_document_drawing_object_ole_data_request import GetDocumentDrawingObjectOleDataRequest
from asposewordscloud.models.requests.get_document_drawing_object_ole_data_without_node_path_request import GetDocumentDrawingObjectOleDataWithoutNodePathRequest
from asposewordscloud.models.requests.get_document_drawing_objects_request import GetDocumentDrawingObjectsRequest
from asposewordscloud.models.requests.get_document_drawing_objects_without_node_path_request import GetDocumentDrawingObjectsWithoutNodePathRequest
from asposewordscloud.models.requests.get_document_field_names_request import GetDocumentFieldNamesRequest
from asposewordscloud.models.requests.get_document_field_names_online_request import GetDocumentFieldNamesOnlineRequest
from asposewordscloud.models.requests.get_document_hyperlink_by_index_request import GetDocumentHyperlinkByIndexRequest
from asposewordscloud.models.requests.get_document_hyperlinks_request import GetDocumentHyperlinksRequest
from asposewordscloud.models.requests.get_document_properties_request import GetDocumentPropertiesRequest
from asposewordscloud.models.requests.get_document_property_request import GetDocumentPropertyRequest
from asposewordscloud.models.requests.get_document_protection_request import GetDocumentProtectionRequest
from asposewordscloud.models.requests.get_document_statistics_request import GetDocumentStatisticsRequest
from asposewordscloud.models.requests.get_document_with_format_request import GetDocumentWithFormatRequest
from asposewordscloud.models.requests.get_field_request import GetFieldRequest
from asposewordscloud.models.requests.get_fields_request import GetFieldsRequest
from asposewordscloud.models.requests.get_fields_without_node_path_request import GetFieldsWithoutNodePathRequest
from asposewordscloud.models.requests.get_field_without_node_path_request import GetFieldWithoutNodePathRequest
from asposewordscloud.models.requests.get_files_list_request import GetFilesListRequest
from asposewordscloud.models.requests.get_footnote_request import GetFootnoteRequest
from asposewordscloud.models.requests.get_footnotes_request import GetFootnotesRequest
from asposewordscloud.models.requests.get_footnotes_without_node_path_request import GetFootnotesWithoutNodePathRequest
from asposewordscloud.models.requests.get_footnote_without_node_path_request import GetFootnoteWithoutNodePathRequest
from asposewordscloud.models.requests.get_form_field_request import GetFormFieldRequest
from asposewordscloud.models.requests.get_form_fields_request import GetFormFieldsRequest
from asposewordscloud.models.requests.get_form_fields_without_node_path_request import GetFormFieldsWithoutNodePathRequest
from asposewordscloud.models.requests.get_form_field_without_node_path_request import GetFormFieldWithoutNodePathRequest
from asposewordscloud.models.requests.get_header_footer_request import GetHeaderFooterRequest
from asposewordscloud.models.requests.get_header_footer_of_section_request import GetHeaderFooterOfSectionRequest
from asposewordscloud.models.requests.get_header_footers_request import GetHeaderFootersRequest
from asposewordscloud.models.requests.get_list_request import GetListRequest
from asposewordscloud.models.requests.get_lists_request import GetListsRequest
from asposewordscloud.models.requests.get_office_math_object_request import GetOfficeMathObjectRequest
from asposewordscloud.models.requests.get_office_math_objects_request import GetOfficeMathObjectsRequest
from asposewordscloud.models.requests.get_office_math_objects_without_node_path_request import GetOfficeMathObjectsWithoutNodePathRequest
from asposewordscloud.models.requests.get_office_math_object_without_node_path_request import GetOfficeMathObjectWithoutNodePathRequest
from asposewordscloud.models.requests.get_paragraph_request import GetParagraphRequest
from asposewordscloud.models.requests.get_paragraph_format_request import GetParagraphFormatRequest
from asposewordscloud.models.requests.get_paragraph_format_without_node_path_request import GetParagraphFormatWithoutNodePathRequest
from asposewordscloud.models.requests.get_paragraph_list_format_request import GetParagraphListFormatRequest
from asposewordscloud.models.requests.get_paragraph_list_format_without_node_path_request import GetParagraphListFormatWithoutNodePathRequest
from asposewordscloud.models.requests.get_paragraphs_request import GetParagraphsRequest
from asposewordscloud.models.requests.get_paragraphs_without_node_path_request import GetParagraphsWithoutNodePathRequest
from asposewordscloud.models.requests.get_paragraph_tab_stops_request import GetParagraphTabStopsRequest
from asposewordscloud.models.requests.get_paragraph_tab_stops_without_node_path_request import GetParagraphTabStopsWithoutNodePathRequest
from asposewordscloud.models.requests.get_paragraph_without_node_path_request import GetParagraphWithoutNodePathRequest
from asposewordscloud.models.requests.get_range_text_request import GetRangeTextRequest
from asposewordscloud.models.requests.get_run_request import GetRunRequest
from asposewordscloud.models.requests.get_run_font_request import GetRunFontRequest
from asposewordscloud.models.requests.get_runs_request import GetRunsRequest
from asposewordscloud.models.requests.get_section_request import GetSectionRequest
from asposewordscloud.models.requests.get_section_page_setup_request import GetSectionPageSetupRequest
from asposewordscloud.models.requests.get_sections_request import GetSectionsRequest
from asposewordscloud.models.requests.get_style_request import GetStyleRequest
from asposewordscloud.models.requests.get_style_from_document_element_request import GetStyleFromDocumentElementRequest
from asposewordscloud.models.requests.get_styles_request import GetStylesRequest
from asposewordscloud.models.requests.get_table_request import GetTableRequest
from asposewordscloud.models.requests.get_table_cell_request import GetTableCellRequest
from asposewordscloud.models.requests.get_table_cell_format_request import GetTableCellFormatRequest
from asposewordscloud.models.requests.get_table_properties_request import GetTablePropertiesRequest
from asposewordscloud.models.requests.get_table_properties_without_node_path_request import GetTablePropertiesWithoutNodePathRequest
from asposewordscloud.models.requests.get_table_row_request import GetTableRowRequest
from asposewordscloud.models.requests.get_table_row_format_request import GetTableRowFormatRequest
from asposewordscloud.models.requests.get_tables_request import GetTablesRequest
from asposewordscloud.models.requests.get_tables_without_node_path_request import GetTablesWithoutNodePathRequest
from asposewordscloud.models.requests.get_table_without_node_path_request import GetTableWithoutNodePathRequest
from asposewordscloud.models.requests.insert_comment_request import InsertCommentRequest
from asposewordscloud.models.requests.insert_drawing_object_request import InsertDrawingObjectRequest
from asposewordscloud.models.requests.insert_drawing_object_without_node_path_request import InsertDrawingObjectWithoutNodePathRequest
from asposewordscloud.models.requests.insert_field_request import InsertFieldRequest
from asposewordscloud.models.requests.insert_field_without_node_path_request import InsertFieldWithoutNodePathRequest
from asposewordscloud.models.requests.insert_footnote_request import InsertFootnoteRequest
from asposewordscloud.models.requests.insert_footnote_without_node_path_request import InsertFootnoteWithoutNodePathRequest
from asposewordscloud.models.requests.insert_form_field_request import InsertFormFieldRequest
from asposewordscloud.models.requests.insert_form_field_without_node_path_request import InsertFormFieldWithoutNodePathRequest
from asposewordscloud.models.requests.insert_header_footer_request import InsertHeaderFooterRequest
from asposewordscloud.models.requests.insert_list_request import InsertListRequest
from asposewordscloud.models.requests.insert_or_update_paragraph_tab_stop_request import InsertOrUpdateParagraphTabStopRequest
from asposewordscloud.models.requests.insert_or_update_paragraph_tab_stop_without_node_path_request import InsertOrUpdateParagraphTabStopWithoutNodePathRequest
from asposewordscloud.models.requests.insert_page_numbers_request import InsertPageNumbersRequest
from asposewordscloud.models.requests.insert_paragraph_request import InsertParagraphRequest
from asposewordscloud.models.requests.insert_paragraph_without_node_path_request import InsertParagraphWithoutNodePathRequest
from asposewordscloud.models.requests.insert_run_request import InsertRunRequest
from asposewordscloud.models.requests.insert_style_request import InsertStyleRequest
from asposewordscloud.models.requests.insert_table_request import InsertTableRequest
from asposewordscloud.models.requests.insert_table_cell_request import InsertTableCellRequest
from asposewordscloud.models.requests.insert_table_row_request import InsertTableRowRequest
from asposewordscloud.models.requests.insert_table_without_node_path_request import InsertTableWithoutNodePathRequest
from asposewordscloud.models.requests.insert_watermark_image_request import InsertWatermarkImageRequest
from asposewordscloud.models.requests.insert_watermark_text_request import InsertWatermarkTextRequest
from asposewordscloud.models.requests.load_web_document_request import LoadWebDocumentRequest
from asposewordscloud.models.requests.move_file_request import MoveFileRequest
from asposewordscloud.models.requests.move_folder_request import MoveFolderRequest
from asposewordscloud.models.requests.protect_document_request import ProtectDocumentRequest
from asposewordscloud.models.requests.reject_all_revisions_request import RejectAllRevisionsRequest
from asposewordscloud.models.requests.remove_range_request import RemoveRangeRequest
from asposewordscloud.models.requests.render_drawing_object_request import RenderDrawingObjectRequest
from asposewordscloud.models.requests.render_drawing_object_without_node_path_request import RenderDrawingObjectWithoutNodePathRequest
from asposewordscloud.models.requests.render_math_object_request import RenderMathObjectRequest
from asposewordscloud.models.requests.render_math_object_without_node_path_request import RenderMathObjectWithoutNodePathRequest
from asposewordscloud.models.requests.render_page_request import RenderPageRequest
from asposewordscloud.models.requests.render_paragraph_request import RenderParagraphRequest
from asposewordscloud.models.requests.render_paragraph_without_node_path_request import RenderParagraphWithoutNodePathRequest
from asposewordscloud.models.requests.render_table_request import RenderTableRequest
from asposewordscloud.models.requests.render_table_without_node_path_request import RenderTableWithoutNodePathRequest
from asposewordscloud.models.requests.replace_text_request import ReplaceTextRequest
from asposewordscloud.models.requests.replace_with_text_request import ReplaceWithTextRequest
from asposewordscloud.models.requests.reset_cache_request import ResetCacheRequest
from asposewordscloud.models.requests.save_as_request import SaveAsRequest
from asposewordscloud.models.requests.save_as_range_request import SaveAsRangeRequest
from asposewordscloud.models.requests.save_as_tiff_request import SaveAsTiffRequest
from asposewordscloud.models.requests.search_request import SearchRequest
from asposewordscloud.models.requests.split_document_request import SplitDocumentRequest
from asposewordscloud.models.requests.unprotect_document_request import UnprotectDocumentRequest
from asposewordscloud.models.requests.update_bookmark_request import UpdateBookmarkRequest
from asposewordscloud.models.requests.update_border_request import UpdateBorderRequest
from asposewordscloud.models.requests.update_comment_request import UpdateCommentRequest
from asposewordscloud.models.requests.update_drawing_object_request import UpdateDrawingObjectRequest
from asposewordscloud.models.requests.update_drawing_object_without_node_path_request import UpdateDrawingObjectWithoutNodePathRequest
from asposewordscloud.models.requests.update_field_request import UpdateFieldRequest
from asposewordscloud.models.requests.update_fields_request import UpdateFieldsRequest
from asposewordscloud.models.requests.update_footnote_request import UpdateFootnoteRequest
from asposewordscloud.models.requests.update_footnote_without_node_path_request import UpdateFootnoteWithoutNodePathRequest
from asposewordscloud.models.requests.update_form_field_request import UpdateFormFieldRequest
from asposewordscloud.models.requests.update_form_field_without_node_path_request import UpdateFormFieldWithoutNodePathRequest
from asposewordscloud.models.requests.update_list_request import UpdateListRequest
from asposewordscloud.models.requests.update_list_level_request import UpdateListLevelRequest
from asposewordscloud.models.requests.update_paragraph_format_request import UpdateParagraphFormatRequest
from asposewordscloud.models.requests.update_paragraph_format_without_node_path_request import UpdateParagraphFormatWithoutNodePathRequest
from asposewordscloud.models.requests.update_paragraph_list_format_request import UpdateParagraphListFormatRequest
from asposewordscloud.models.requests.update_paragraph_list_format_without_node_path_request import UpdateParagraphListFormatWithoutNodePathRequest
from asposewordscloud.models.requests.update_run_request import UpdateRunRequest
from asposewordscloud.models.requests.update_run_font_request import UpdateRunFontRequest
from asposewordscloud.models.requests.update_section_page_setup_request import UpdateSectionPageSetupRequest
from asposewordscloud.models.requests.update_style_request import UpdateStyleRequest
from asposewordscloud.models.requests.update_table_cell_format_request import UpdateTableCellFormatRequest
from asposewordscloud.models.requests.update_table_properties_request import UpdateTablePropertiesRequest
from asposewordscloud.models.requests.update_table_properties_without_node_path_request import UpdateTablePropertiesWithoutNodePathRequest
from asposewordscloud.models.requests.update_table_row_format_request import UpdateTableRowFormatRequest
from asposewordscloud.models.requests.upload_file_request import UploadFileRequest
